@@ -22,8 +22,8 @@
 
 '''Command classes for mind map modification'''
 
-from PySide.QtGui import *
-from hivemind.attribute import *
+from PySide.QtGui import QUndoCommand
+from hivemind.attribute import readable
 
 
 class AddNodeCommand(QUndoCommand):
