@@ -141,6 +141,18 @@ class MindMap(object):
         '''
         return self.__idToNode.get(nodeId)
 
+    def clone(self):
+        '''
+        Create a clone of the current mind map
+        @rtype: MindMap
+        '''
+        rootClone = self.__root.cloneTree()
+        if self.__attributeRegistry:
+            attributeRegistry = AttributeRegistry(**self.__attributeRegistry.attributes)
+        else:
+            attributeRegistry = None
+        return MindMap(rootClone, attributeRegistry)
+
 
 class Node(Element, Observable):
     '''
@@ -499,6 +511,11 @@ class Node(Element, Observable):
             'nodeAttribute', 'note', 'hgap', 'vgap', 'vshift'))
     '''Properties which not emit any notifications and not has a setter'''
 
+    __TEXT_ATTRIBUTES = set(('text', 'html'))
+    '''
+    Node text properties, they are part of the local attributes that need special treatment.
+    '''
+
     __LOCAL_CHANGE_LEVEL, __INHERITED_CHANGE_LEVEL = range(2)
     '''Numerical constants of signal types'''
 
@@ -514,16 +531,12 @@ class Node(Element, Observable):
         '''
         maxNotifyLevel = -1 # -1 <=> no notification will be send
         for attrName, attrValue in attributes.items():
-            if attrName == 'text':
-                self._setPlainText(attrValue)
-                maxNotifyLevel = max(maxNotifyLevel, Node.__LOCAL_CHANGE_LEVEL)
-            elif attrName == 'html':
-                self._setHtml(attrValue)
-                maxNotifyLevel = max(maxNotifyLevel, Node.__LOCAL_CHANGE_LEVEL)
-            elif attrName in Node.__INHERITED_ATTRIBUTES:
-                setter = getattr(self, '_set%s%s' % (attrName[0].upper(), attrName[1:]))
-                setter(attrValue)
+            if attrName in Node.__INHERITED_ATTRIBUTES:
+                self._setAttribute(attrName, attrValue)
                 maxNotifyLevel = max(maxNotifyLevel, Node.__INHERITED_CHANGE_LEVEL)
+            elif attrName in Node.__TEXT_ATTRIBUTES:
+                self._setAttribute(attrName, attrValue)
+                maxNotifyLevel = max(maxNotifyLevel, Node.__LOCAL_CHANGE_LEVEL)
             elif attrName in Node.__LOCAL_ATTRIBUTES:
                 self._setField(attrName, attrValue)
                 maxNotifyLevel = max(maxNotifyLevel, Node.__LOCAL_CHANGE_LEVEL)
@@ -534,11 +547,17 @@ class Node(Element, Observable):
         if maxNotifyLevel != -1:
             self.notifyObservers(self, type = Node.__SIGNALS[maxNotifyLevel])
 
-    WRITABLE_PROPERTIES = ('created', 'id', 'modified', 'encrypted_content', 'nodeAttribute',
-            'note', 'icons', 'font', 'color', 'left', 'edgeColor', 'edgeWidth', 'edgeStyle',
-            'link', 'hgap', 'vgap', 'vshift', 'cloud', 'folded', 'backgroundColor', 'style',
-            'text', 'labelText', 'labelFont', 'labelColor', 'propagateNodeFormatting',
-            'propagateLabelFormatting')
+    def _setAttribute(self, attributeName, attributeValue):
+        '''
+        Use setter to set new value for the attribute identified by attributeName
+        @type attributeName: str
+        @param attributeValue: value for the attribute
+        '''
+        setter = getattr(self, '_set%s%s' % (attributeName[0].upper(), attributeName[1:]))
+        setter(attributeValue)
+
+    WRITABLE_PROPERTIES = __LOCAL_ATTRIBUTES.union(__INHERITED_ATTRIBUTES).union(
+            __NONEVENT_ATTRIBUTES).union(__TEXT_ATTRIBUTES)
     '''Node writable properties that can be set with setAttributes() method'''
 
     def getAttributes(self, *propNames, **options):
@@ -555,10 +574,14 @@ class Node(Element, Observable):
         resultAttributes = {}
         if options.get('getAll'):
             propNames = Node.WRITABLE_PROPERTIES
+        propNames = list(propNames)
         # automatically choose content type to be returned)
-        if 'text' in propNames:
-            propNames = list(propNames)
-            propNames.remove('text')
+        found = False
+        for textAttribute in Node.__TEXT_ATTRIBUTES:
+            if textAttribute in propNames:
+                propNames.remove(textAttribute)
+                found = True
+        if found:
             if self.__isHtmlContent:
                 resultAttributes['html'] = self.text
             else:
@@ -584,7 +607,7 @@ class Node(Element, Observable):
         '''
         return self.__isHtmlContent
 
-    def _setPlainText(self, text):
+    def _setText(self, text):
         '''
         Set node content as simple text
         '''
@@ -801,6 +824,31 @@ class Node(Element, Observable):
                       self.__labelFontMetrics.overlinePos() -
                       self.__labelFontMetrics.underlinePos())
 
+    __PARENT_ATTRIBUTES = set(('parentFont', 'parentColor', 'parentBackgroundColor',
+            'parentStyle', 'parentLabelColor', 'parentLabelFont', 'parentEdgeWidth',
+            'parentEdgeStyle', 'parentEdgeColor'))
+    def clone(self):
+        '''
+        Clone current node and return it's cloned copy
+        @rtype: Node
+        '''
+        clone = Node()
+        clone.setAttributes(**self.getAttributes(getAll = True))
+        for attribute in Node.__PARENT_ATTRIBUTES:
+            attrName = '_Node__%s' % attribute
+            clone.__dict__[attrName] = self.__dict__[attrName]
+        return clone
+
+    def cloneTree(self):
+        '''
+        Create a clone of the current node and it's subtree
+        @rtype: Node
+        '''
+        clone = self.clone()
+        for child in self.__children:
+            clone.addChild(child.cloneTree())
+        return clone
+
 
 class Cloud(Element):
     '''
