@@ -30,7 +30,8 @@ QVBoxLayout, QGroupBox, QWidget
 from PySide.QtCore import SIGNAL, QSize, Qt
 from hivemind.dialogs import EditNodeDialog, EditLabelDialog, IconDialog, \
 AboutDialog, EditEdgeDialog, SettingsDialog, NetworkConnectionDialog, \
-AffiliationDialog, SettingsCreator, NetworkServiceDialog, NetworkClientDialog
+AffiliationDialog, NetworkServiceDialog, NetworkClientDialog
+from hivemind.gui_widgets import SettingsCreator
 from hivemind.attribute import adaptCallable
 import hivemind.__version__ as __version__
 
@@ -55,6 +56,8 @@ class DesktopEditNodeDialog(EditNodeDialog):
         '''Form initialization'''
         #pylint: disable = W0201
         toolbar = QToolBar(self)
+        toolbar.addWidget(self._comboFont)
+        toolbar.addWidget(self._comboSize)
         self._boldAction.setToolTip(self.tr('Bold'))
         self._boldAction.setIcon(QIcon.fromTheme('format-text-bold'))
         toolbar.addAction(self._boldAction)
@@ -79,20 +82,21 @@ class DesktopEditNodeDialog(EditNodeDialog):
         self.__tabWidget = QTabWidget(self)
         self.__textIndex = self.__tabWidget.addTab(self._editor, self.tr('Text'))
         self.__htmlIndex = self.__tabWidget.addTab(self._htmlEditor, 'Html')
-        gridLayout = QGridLayout(self)
-        gridLayout.addWidget(self._fontToolbar, 0, 0, 1, 2)
-        gridLayout.addWidget(toolbar, 0, 2, 1, 2)
-        gridLayout.addWidget(self.__tabWidget, 1, 0, 1, 4)
+        mainLayout = QVBoxLayout()
+        mainLayout.addWidget(toolbar)
+        mainLayout.addWidget(self.__tabWidget)
         lastLineLayout = QHBoxLayout()
         lastLineLayout.addWidget(self._propagateFormatting)
         lastLineLayout.addStretch()
         lastLineLayout.addWidget(self._buttonBox)
-        gridLayout.addLayout(lastLineLayout, 2, 0, 1, 4)
+        mainLayout.addLayout(lastLineLayout)
         QWidget.setTabOrder(self._editor, self.__tabWidget)
         self._textHtmlAction.connect(SIGNAL('toggled(bool)'),
                 adaptCallable(self._enableSourceTab))
         self.__tabWidget.connect(SIGNAL('currentChanged(int)'),
                 adaptCallable(self._changedMode))
+        self.setLayout(mainLayout)
+        self._editor.setFocus()
 
     def _changedMode(self, isSourceMode):
         '''
@@ -147,9 +151,9 @@ class DesktopEditLabelDialog(EditLabelDialog):
         self._underlineAction.setIcon(QIcon.fromTheme('format-text-underline'))
         toolbar.addAction(self._underlineAction)
         secondaryLayout = QHBoxLayout()
-        secondaryLayout.addWidget(self._fontParent)
+        secondaryLayout.addWidget(self._parentFont)
         secondaryLayout.addSpacing(20)
-        secondaryLayout.addWidget(self._colorParent)
+        secondaryLayout.addWidget(self._parentColor)
         secondaryLayout.addWidget(self._colorButton)
         mainLayout = QGridLayout()
         mainLayout.addWidget(toolbar, 0, 0, 1, 2)
@@ -232,54 +236,30 @@ class DesktopAboutDialog(AboutDialog):
         about = QTextBrowser()
         about.setFrameStyle(QFrame.NoFrame)
         about.setOpenExternalLinks(True)
-        about.setHtml(self.tr('''HiveMind - Collaborative mind map editor<br>
-            Copyright &copy; 2010-2011 HiveMind developers<br><br>
-            License: <a href="http://www.gnu.org/licenses/gpl-3.0.html">
-            GNU General Public License Version 3</a><br><br>
-            HiveMind development is supported by<br>
-            <a href="http://fruct.org/"> Open Innovations Framework Program FRUCT</a>
-            '''))
-        self._tabWidget.addTab(about, '&About')
+        about.setHtml('%s - %s<br>%s<br><br>%s<br><br>%s<br>%s<br>' %
+                (self._appName, self._appDescription, self._copyright, self._license,
+                self._development, self._linkTemplate % (self._fructLink, self._fruct)))
+        self._tabWidget.addTab(about, self.tr('&About'))
         authors = QTextBrowser()
         authors.setFrameStyle(QFrame.NoFrame)
         authors.setOpenExternalLinks(True)
-        authors.setHtml(self.tr('''
-            Please use <a href="https://linuxlab.corp7.uniyar.ac.ru/projects/hivemind/issues/new">
-            https://linuxlab.corp7.uniyar.ac.ru/</a> to report bugs.<br><br>
-            Andrey Golovchenko<br>
-            &nbsp;&nbsp;<a href="mailto:golovchenkoaa@gmail.com">golovchenkoaa@gmail.com</a><br>
-            &nbsp;&nbsp;core developer<br>
-            <br>
-            Andrey Vasilev<br>
-            &nbsp;&nbsp;<a href="mailto:vamonster@gmail.com">vamonster@gmail.com</a><br>
-            &nbsp;&nbsp;developer/designer<br>
-            <br>
-            Alexander Kulikov<br>
-            &nbsp;&nbsp;<a href="mailto:asgard1988@yandex.ru">asgard1988@yandex.ru</a><br>
-            &nbsp;&nbsp;developer<br>
-            <br>
-            Oleg Kandaurov<br>
-            &nbsp;&nbsp;<a href="mailto:kandaurov.oleg@gmail.com">kandaurov.oleg@gmail.com</a><br>
-            &nbsp;&nbsp;developer<br>
-            <br>
-            Ilya Paramonov<br>
-            &nbsp;&nbsp;<a href="mailto:ivparamonov@gmail.com">ivparamonov@gmail.com</a><br>
-            &nbsp;&nbsp;technical manager<br>
-            '''))
-        self._tabWidget.addTab(authors, 'A&uthors')
+        bugReport = self.tr('Please use %s to report bugs') % (self._linkTemplate %
+                (self._bugLink, self._siteLink))
+        authors.setHtml('%s<br>' % (bugReport) +
+                self._generateInfo(self._authorInfo, 'AndreyVasilev') +
+                self._generateInfo(self._authorInfo, 'OlegKandaurov') +
+                self._generateInfo(self._authorInfo, 'AlexanderKulikov') +
+                self._generateInfo(self._authorInfo, 'IlyaParamonov') +
+                self._generateInfo(self._authorInfo, 'AndreyGolovchenko'))
+        self._tabWidget.addTab(authors, self.tr('A&uthors'))
         thanks = QTextBrowser()
         thanks.setFrameStyle(QFrame.NoFrame)
         thanks.setOpenExternalLinks(True)
-        thanks.setHtml(self.tr('''
-            Nicu Buculei<br>
-            &nbsp;&nbsp;<a href="http://nicubunu.ro">nicubunu.ro</a><br>
-            &nbsp;&nbsp;HiveMind logo<br><br>
-            Mentalrey<br>
-            &nbsp;&nbsp;<a href="http://www.mentalrey.it/">mentalrey.it</a><br>
-            &nbsp;&nbsp;Notification icons<br>'''))
-        self._tabWidget.addTab(thanks, '&Thanks To')
-        self._name = QLabel('<h2>HiveMind</h2>')
-        self._version = QLabel(self.tr('<h4>Version %s</h4>') % __version__.VERSION)
+        thanks.setHtml(self._generateInfo(self._participantInfo, 'NicuBuculei') +
+                self._generateInfo(self._participantInfo, 'Mentalrey'))
+        self._tabWidget.addTab(thanks, self.tr('&Thanks To'))
+        self._name = QLabel('<h2>%s</h2>' % self._appName)
+        self._version = QLabel('<h4>%s</h4>' % self.tr('Version %s') % __version__.VERSION)
 
     def _initComponents(self):
         '''Form initialization'''
@@ -302,6 +282,16 @@ class DesktopAboutDialog(AboutDialog):
         self.setLayout(mainLayout)
         close.connect(SIGNAL('rejected()'), self.close)
 
+    def _generateInfo(self, info, name):
+        '''
+        Generate formatted information about person
+        @type info: dict
+        @type name: str
+        '''
+        infoTemplate = ('<br>%s<br>&nbsp;&nbsp;<a href="%s">%s</a><br>&nbsp;&nbsp;%s<br>')
+        return infoTemplate % (info[name]['name'], info[name]['site'], info[name]['site'],
+                info[name]['role'])
+
 
 class DesktopEditEdgeDialog(EditEdgeDialog):
     '''
@@ -319,7 +309,8 @@ class DesktopEditEdgeDialog(EditEdgeDialog):
     def _initComponents(self):
         '''Form initialization'''
         colorLayout = QHBoxLayout()
-        colorLayout.addWidget(self._colorParent)
+        colorLayout.addWidget(self._parentColor)
+        colorLayout.addWidget(self._colorLabel)
         colorLayout.addWidget(self._colorButton)
         mainLayout = QGridLayout()
         mainLayout.addWidget(self._widthLabel, 0, 0)
@@ -343,26 +334,29 @@ class DesktopSettingsDialog(SettingsDialog):
         @type parent: QWidget
         '''
         SettingsDialog.__init__(self, parent)
-        self._general = SettingsCreator(['locale', 'defaultZoomLevel', 'confirmDelete'])
-        generalGroup = QGroupBox(self.tr('General settings'))
-        generalGroup.setLayout(self._general.getLayout())
-        self._node = SettingsCreator(['defaultFont', 'defaultNodeTextColor',
-                'defaultNodeBackgroundColor', 'defaultSelectedNodeBackgroundColor',
+        self._general = SettingsCreator(['locale', 'confirmDelete', 'defaultZoomLevel',
                 'maxNodeTextWidth'])
-        nodeGroup = QGroupBox(self.tr('Node settings'))
-        nodeGroup.setLayout(self._node.getLayout())
+        generalTab = QWidget()
+        generalTab.setLayout(self._general.getLayout())
+        self._node = SettingsCreator(['defaultFont', 'defaultNodeTextColor',
+                'defaultNodeBackgroundColor', 'defaultSelectedNodeBackgroundColor'])
+        nodeTab = QWidget()
+        nodeTab.setLayout(self._node.getLayout())
         self._edge = SettingsCreator(['defaultLabelFont', 'defaultLabelColor',
                 'defaultEdgeWidth', 'defaultEdgeColor'])
-        edgeGroup = QGroupBox(self.tr('Edge && label settings'))
-        edgeGroup.setLayout(self._edge.getLayout())
+        edgeTab = QWidget()
+        edgeTab.setLayout(self._edge.getLayout())
         self._autosave = SettingsCreator(['autosaveEnabled', 'autosaveInterval'])
-        autosaveGroup = QGroupBox(self.tr('Autosave settings'))
-        autosaveGroup.setLayout(self._autosave.getLayout())
+        autosaveTab = QWidget()
+        autosaveTab.setLayout(self._autosave.getLayout())
+        tabWidget = QTabWidget()
+        tabWidget.addTab(generalTab, self.tr('General'))
+        tabWidget.addTab(nodeTab, self.tr('Node'))
+        tabWidget.addTab(edgeTab, self.tr('Edge && label'))
+        tabWidget.addTab(autosaveTab, self.tr('Autosave'))
+        tabWidget.setUsesScrollButtons(False)
         mainLayout = QVBoxLayout()
-        mainLayout.addWidget(generalGroup)
-        mainLayout.addWidget(nodeGroup)
-        mainLayout.addWidget(edgeGroup)
-        mainLayout.addWidget(autosaveGroup)
+        mainLayout.addWidget(tabWidget)
         mainLayout.addWidget(self._buttonBox)
         self.setLayout(mainLayout)
 
