@@ -109,9 +109,7 @@ class DesktopMainWindow(AbstractMainWindow):
                 self._actionBag.addSiblingNodeAboveAction, self._actionBag.editNodeAction,
                 self._actionBag.editNodeIconsAction, self._actionBag.editLabelAction,
                 self._actionBag.editEdgeAction, self._actionBag.editAffiliationAction,
-                self._actionBag.connectXMPPAction, self._actionBag.createServiceAction,
-                self._actionBag.createClientAction, self._actionBag.startServiceAction,
-                self._actionBag.startClientAction]
+                self._actionBag.startServiceAction, self._actionBag.startClientAction]
         for action in actionsWithEllipses:
             action.setText(action.text() + '...')
 
@@ -131,16 +129,11 @@ class DesktopMainWindow(AbstractMainWindow):
         menu.addSeparator()
         menu.addAction(self._actionBag.settingsAction)
         menu = self.menuBar().addMenu(self.tr('&Network'))
-        advMenu = QMenu(self.tr('&Advanced'))
-        advMenu.addAction(self._actionBag.connectXMPPAction)
-        advMenu.addAction(self._actionBag.createServiceAction)
-        advMenu.addAction(self._actionBag.createClientAction)
-        advMenu.addAction(self._actionBag.stopProtocolAction)
-        menu.addMenu(advMenu)
         menu.addAction(self._actionBag.startServiceAction)
         menu.addAction(self._actionBag.startClientAction)
-        menu.addAction(self._actionBag.disconnectXMPPAction)
         menu.addAction(self._actionBag.editAffiliationAction)
+        menu.addAction(self._actionBag.stopProtocolAction)
+        menu.addAction(self._actionBag.disconnectXMPPAction)
         menu = self.menuBar().addMenu(self.tr('&Help'))
         menu.addAction(self._actionBag.aboutAction)
 
@@ -163,5 +156,4 @@ class DesktopMainWindow(AbstractMainWindow):
 
     def showMenu(self, rightButton, item):
         '''Show the node menu on right button click'''
-        if rightButton:
-            self.__menu.exec_(QCursor.pos())
+        self.__menu.exec_(QCursor.pos())
