@@ -29,20 +29,31 @@ import hivemind.settings as settings
 import hivemind.resource as resource
 from PySide.QtGui import QDialog, QMessageBox, QDialogButtonBox, QLabel, QLineEdit, \
 QVBoxLayout, QFormLayout, QAbstractItemView, QTableView, QHeaderView, QHBoxLayout, \
-QRadioButton, QButtonGroup, QComboBox, QPushButton, QToolBar, QFontComboBox, QAction, \
-QFontDatabase, QColorDialog, QTextCharFormat, QFont, QPalette, QBrush, QTextCursor, \
-QGridLayout, QCheckBox, QGraphicsView
-from PySide.QtCore import SIGNAL, QRegExp, Qt, QSize, SLOT
+QRadioButton, QButtonGroup, QComboBox, QPushButton, QFontComboBox, QAction, QFontDatabase, \
+QColorDialog, QTextCharFormat, QFont, QPalette, QBrush, QTextCursor, QGridLayout, QCheckBox, \
+QGraphicsView, QGroupBox
+from PySide.QtCore import SIGNAL, QRegExp, Qt, QSize, SLOT, QCoreApplication
 from hivemind.attribute import readable, adaptCallable
 from hivemind.gui_widgets import SearchingTrMixin, SpecialTextEdit, \
-ScalingWidget, IconList, IconTable, LineEditBinder, CheckBoxBinder, \
-SettingsCreator
+ScalingWidget, IconList, IconTable, LineEditBinder, CheckBoxBinder, ColorLabel
 from hivemind.network.network_models import AffiliationDelegate
 from twisted.words.protocols.jabber import jid
 
 '''Regexp for jid validation'''
 VALID_JID = '[A-Za-z0-9._%+-]+@(?:[A-Za-z0-9-]+\\.)+[A-Za-z]{2,6}'
 
+
+def _showJIDErrorDialog(parent):
+    '''
+    Show dialog that presents JID error
+    @param parent: parent of the error dialog
+    @type parent: QWidget
+    '''
+    QMessageBox.warning(parent, QCoreApplication.translate('JIDErrorDialog', 'Incorrect JID!'),
+            QCoreApplication.translate('JIDErrorDialog', 'Please, enter correct JID ' +
+                    '(e.g. test@example.net)'))
+
+
 class CommonDialog(SearchingTrMixin, QDialog):
     '''
     Abstract dialog containing OK and Cancel buttons
@@ -80,8 +91,8 @@ class EditNodeDialog(CommonDialog):
         '''
         CommonDialog.__init__(self, parent)
         self.setWindowTitle(self.tr('Node editor'))
-        self.__node = node
-        self.__background = self.__font = self.__color = None
+        self.__node = node.clone()
+        self.__font = None
         self._isHtml = self.__node.isHtml()
         self.__newAttributes = None
         self._isHtmlSourceMode = False
@@ -97,14 +108,11 @@ class EditNodeDialog(CommonDialog):
         # init html widget
         self._htmlEditor = SpecialTextEdit()
         # create font toolbar
-        self._fontToolbar = QToolBar()
-        self.__comboFont = QFontComboBox()
-        self.__comboSize = QComboBox()
-        self.__comboSize.setEditable(True)
-        self.__comboFont.connect(SIGNAL('currentFontChanged(QFont)'), self._buildFont)
-        self.__comboSize.connect(SIGNAL('currentIndexChanged(int)'), self._buildFont)
-        self._fontToolbar.addWidget(self.__comboFont)
-        self._fontToolbar.addWidget(self.__comboSize)
+        self._comboFont = QFontComboBox()
+        self._comboSize = QComboBox()
+        self._comboSize.setEditable(True)
+        self._comboFont.connect(SIGNAL('currentFontChanged(QFont)'), self._buildFont)
+        self._comboSize.connect(SIGNAL('currentIndexChanged(int)'), self._buildFont)
         # text format actions
         self._boldAction = QAction(self)
         self._boldAction.setCheckable(True)
@@ -151,18 +159,18 @@ class EditNodeDialog(CommonDialog):
         self._boldAction.setChecked(font.bold())
         self._italicAction.setChecked(font.italic())
         self._underlineAction.setChecked(font.underline())
-        self.__comboFont.blockSignals(True)
-        self.__comboSize.blockSignals(True)
-        self.__comboFont.setCurrentFont(font)
-        self.__comboSize.clear()
-        self.__comboSize.addItems([str(value) for value in QFontDatabase().\
-                                   pointSizes(self.__comboFont.currentFont().family())])
-        index = self.__comboSize.findText(str(font.pointSize()), Qt.MatchExactly)
+        self._comboFont.blockSignals(True)
+        self._comboSize.blockSignals(True)
+        self._comboFont.setCurrentFont(font)
+        self._comboSize.clear()
+        self._comboSize.addItems([str(value) for value in QFontDatabase().\
+                                   pointSizes(self._comboFont.currentFont().family())])
+        index = self._comboSize.findText(str(font.pointSize()), Qt.MatchExactly)
         if index == -1:
-            self.__comboSize.setEditText(str(font.pointSize()))
-        else: self.__comboSize.setCurrentIndex(index)
-        self.__comboFont.blockSignals(False)
-        self.__comboSize.blockSignals(False)
+            self._comboSize.setEditText(str(font.pointSize()))
+        else: self._comboSize.setCurrentIndex(index)
+        self._comboFont.blockSignals(False)
+        self._comboSize.blockSignals(False)
 
     def _accept(self):
         '''
@@ -176,10 +184,10 @@ class EditNodeDialog(CommonDialog):
             else:
                 storeAttrs['html'] = self._editor.toHtml()
         else:
-            storeAttrs['font'] = self.__font
+            storeAttrs['font'] = self.__node.font
             storeAttrs['text'] = self._editor.toPlainText()
-        storeAttrs['color'] = self.__color
-        storeAttrs['backgroundColor'] = self.__background
+        storeAttrs['color'] = self.__node.color
+        storeAttrs['backgroundColor'] = self.__node.backgroundColor
         storeAttrs['propagateNodeFormatting'] = self._propagateFormatting.isChecked()
         self.__newAttributes = storeAttrs
         QDialog.accept(self)
@@ -198,7 +206,8 @@ class EditNodeDialog(CommonDialog):
         self._propagateFormatting.setChecked(self.__node.propagateNodeFormatting)
         if self.__node.isHtml():
             self._editor.setHtml(self.__node.text)
-            self.__color = self.__font = None
+            self.__node.setAttributes(color = None)
+            self.__font = None
         else:
             self._editor.setPlainText(self.__node.text)
             self._setFont(self.__node.font)
@@ -217,24 +226,19 @@ class EditNodeDialog(CommonDialog):
 
     def _textColor(self):
         '''Choose font color'''
-        color = QColorDialog.getColor(settings.get('defaultNodeTextColor') \
-                                      if self.__color is None else self.__color,
-                                      self)
+        color = QColorDialog.getColor(self.__node.effectiveColor, self)
         if color.isValid():
             self._setColor(color)
 
     def _textBackground(self):
         '''Choose background text color'''
-        color = QColorDialog.getColor(settings.get('defaultNodeBackgroundColor') \
-                                      if self.__background is None else self.__background,
-                                      self)
+        color = QColorDialog.getColor(self.__node.effectiveBackgroundColor, self)
         if color.isValid():
             self._setBackgroundColor(color)
 
     def _textFont(self):
         '''Edit current font'''
-        fontDialog = FontDialog(settings.get('defaultFont') \
-                                if self.__font is None else self.__font, self)
+        fontDialog = FontDialog(self.__node.effectiveFont, self)
         if fontDialog.exec_() == QDialog.Accepted:
             self._setFont(fontDialog.font)
 
@@ -253,9 +257,7 @@ class EditNodeDialog(CommonDialog):
         if self.__font is None:
             self.__font = self._editor.currentFont()
         self.__font.setBold(checked)
-        fmt = QTextCharFormat()
-        fmt.setFontWeight(QFont.Bold if checked else QFont.Normal)
-        self._mergeFormat(fmt)
+        self._setFont(self.__font)
 
     def _setItalic(self, checked):
         '''
@@ -264,9 +266,7 @@ class EditNodeDialog(CommonDialog):
         if self.__font is None:
             self.__font = self._editor.currentFont()
         self.__font.setItalic(checked)
-        fmt = QTextCharFormat()
-        fmt.setFontItalic(checked)
-        self._mergeFormat(fmt)
+        self._setFont(self.__font)
 
     def _setUnderline(self, checked):
         '''
@@ -275,19 +275,16 @@ class EditNodeDialog(CommonDialog):
         if self.__font is None:
             self.__font = self._editor.currentFont()
         self.__font.setUnderline(checked)
-        fmt = QTextCharFormat()
-        fmt.setFontUnderline(checked)
-        self._mergeFormat(fmt)
+        self._setFont(self.__font)
 
     def _setBackgroundColor(self, color):
         '''
         Set node's background color
         @type color: QColor
         '''
+        self.__node.setAttributes(backgroundColor = color)
         palette = QPalette(self._editor.palette())
-        self.__background = color
-        palette.setColor(QPalette.Base, settings.get('defaultNodeBackgroundColor') \
-                         if color is None else color)
+        palette.setColor(QPalette.Base, self.__node.effectiveBackgroundColor)
         self._editor.setPalette(palette)
 
     def _setColor(self, color):
@@ -295,10 +292,9 @@ class EditNodeDialog(CommonDialog):
         Set node text color
         @type color: QColor
         '''
-        self.__color = color
+        self.__node.setAttributes(color = color)
         fmt = QTextCharFormat()
-        fmt.setForeground(QBrush(settings.get('defaultNodeTextColor') \
-                                 if color is None else color))
+        fmt.setForeground(self.__node.effectiveColor)
         self._mergeFormat(fmt)
 
     def _setFont(self, font):
@@ -306,15 +302,16 @@ class EditNodeDialog(CommonDialog):
         Set node text font
         @type font: QFont
         '''
+        self.__node.setAttributes(font = font)
         self.__font = font
         fmt = QTextCharFormat()
-        fmt.setFont(settings.get('defaultFont') if font is None else font)
+        fmt.setFont(self.__node.effectiveFont)
         self._mergeFormat(fmt)
 
     def _buildFont(self, value):
         '''Build font'''
-        font = self.__comboFont.currentFont()
-        font.setPointSize(int(self.__comboSize.currentText()))
+        font = self._comboFont.currentFont()
+        font.setPointSize(int(self._comboSize.currentText()))
         font.setBold(self._boldAction.isChecked())
         font.setItalic(self._italicAction.isChecked())
         font.setUnderline(self._underlineAction.isChecked())
@@ -429,7 +426,7 @@ class EditLabelDialog(CommonDialog):
         '''
         CommonDialog.__init__(self, parent)
         self.setWindowTitle(self.tr('Edit Label'))
-        self.__node = node
+        self.__node = node.clone()
         self.__color = None
         self.__font = None
         self.__newAttributes = {}
@@ -451,28 +448,28 @@ class EditLabelDialog(CommonDialog):
         self.connect(self._editor, SIGNAL('accept'), self._accept)
         self._comboFont.connect(SIGNAL('currentFontChanged(QFont)'), self._setFont)
         self._comboSize.connect(SIGNAL('currentIndexChanged(int)'), self._setSize)
-        self._colorParent = QCheckBox(self.tr("Parent's color"))
+        self._parentColor = QCheckBox(self.tr("Parent's color"))
         self._colorButton = QPushButton(self.tr('Choose color'))
-        self._fontParent = QCheckBox(self.tr("Parent's font"))
+        self._parentFont = QCheckBox(self.tr("Parent's font"))
         self._propagateFormatting = QCheckBox(self.tr('Propagate formatting to child nodes'))
         self._boldAction.connect(SIGNAL('triggered(bool)'), self._setBold)
         self._italicAction.connect(SIGNAL('triggered(bool)'), self._setItalic)
         self._underlineAction.connect(SIGNAL('triggered(bool)'), self._setUnderline)
         self._colorButton.connect(SIGNAL('clicked()'), self._textColor)
-        self._colorParent.connect(SIGNAL('toggled(bool)'), self._colorButton,
+        self._parentColor.connect(SIGNAL('toggled(bool)'), self._colorButton,
                                   SLOT('setDisabled(bool)'))
-        self._colorParent.connect(SIGNAL('toggled(bool)'), self._updateEditor)
-        self._fontParent.connect(SIGNAL('toggled(bool)'), self._comboFont,
+        self._parentColor.connect(SIGNAL('toggled(bool)'), self._updateEditor)
+        self._parentFont.connect(SIGNAL('toggled(bool)'), self._comboFont,
                                  SLOT('setDisabled(bool)'))
-        self._fontParent.connect(SIGNAL('toggled(bool)'), self._comboSize,
+        self._parentFont.connect(SIGNAL('toggled(bool)'), self._comboSize,
                                  SLOT('setDisabled(bool)'))
-        self._fontParent.connect(SIGNAL('toggled(bool)'), self._boldAction,
+        self._parentFont.connect(SIGNAL('toggled(bool)'), self._boldAction,
                                  SLOT('setDisabled(bool)'))
-        self._fontParent.connect(SIGNAL('toggled(bool)'), self._italicAction,
+        self._parentFont.connect(SIGNAL('toggled(bool)'), self._italicAction,
                                  SLOT('setDisabled(bool)'))
-        self._fontParent.connect(SIGNAL('toggled(bool)'), self._underlineAction,
+        self._parentFont.connect(SIGNAL('toggled(bool)'), self._underlineAction,
                                  SLOT('setDisabled(bool)'))
-        self._fontParent.connect(SIGNAL('toggled(bool)'), self._updateEditor)
+        self._parentFont.connect(SIGNAL('toggled(bool)'), self._updateEditor)
 
     def _initEditor(self):
         '''Initialize editor'''
@@ -480,15 +477,12 @@ class EditLabelDialog(CommonDialog):
         self._editor.document().setDefaultFont(settings.get('defaultLabelFont'))
         self.__font = self.__node.labelFont
         self._setEditorFont(self.__node.labelFont)
+        self._parentFont.setChecked(self.__node.labelFont is None)
         self.__color = self.__node.labelColor
         self._setEditorColor(self.__node.labelColor)
-        if self.__node.labelColor is None:
-            self._colorParent.setChecked(True)
-        if self.__node.labelFont is None:
-            self._fontParent.setChecked(True)
+        self._parentColor.setChecked(self.__node.labelColor is None)
         self._comboSize.setEditable(True)
-        font = self.__node.effectiveLabelFont
-        self._comboFont.setCurrentFont(font)
+        self._comboFont.setCurrentFont(self.__node.effectiveLabelFont)
         self._propagateFormatting.setChecked(self.__node.propagateLabelFormatting)
         self._editor.selectAll()
 
@@ -498,9 +492,11 @@ class EditLabelDialog(CommonDialog):
 
         @type font: QFont
         '''
+        self._comboSize.blockSignals(True)
         self._comboSize.clear()
         self._comboSize.addItems([str(value) for value in QFontDatabase().\
                                    pointSizes(font.family())])
+        self._comboSize.blockSignals(False)
 
     def _setSizeIndex(self, font):
         '''
@@ -530,17 +526,13 @@ class EditLabelDialog(CommonDialog):
 
         @type font: QFont
         '''
-        if font is None:
-            font = self.__node.effectiveLabelFont
         if self._comboSize.currentText() != '':
             font.setPointSize(int(self._comboSize.currentText()))
         self._fontSizes(font)
         self._setSizeIndex(font)
         self._setEditorFont(font)
         self._updateButtonsState(font)
-        # don't save current formatting if parent button checked
-        if not self._fontParent.isChecked():
-            self.__font = font
+        self.__font = font
 
     def _setSize(self, index):
         '''
@@ -553,42 +545,28 @@ class EditLabelDialog(CommonDialog):
             font.setPointSize(int(self._comboSize.itemText(index)))
         self._setEditorFont(font)
         self._updateButtonsState(font)
-        # don't save current formatting if parent button checked
-        if not self._fontParent.isChecked():
-            self.__font = font
+        self.__font = font
 
     def _setBold(self, checked):
         '''
         Update text editor if Bold button has triggered
         '''
-        fmt = QTextCharFormat()
-        fmt.setFontWeight(QFont.Bold if checked else QFont.Normal)
-        self._mergeFormat(fmt)
-        # don't save current formatting if parent button checked
-        if not self._fontParent.isChecked():
-            self.__font.setBold(checked)
+        self.__font.setBold(checked)
+        self._setEditorFont(self.__font)
 
     def _setItalic(self, checked):
         '''
         Update text editor if Italic button has triggered
         '''
-        fmt = QTextCharFormat()
-        fmt.setFontItalic(checked)
-        self._mergeFormat(fmt)
-        # don't save current formatting if parent button checked
-        if not self._fontParent.isChecked():
-            self.__font.setItalic(checked)
+        self.__font.setItalic(checked)
+        self._setEditorFont(self.__font)
 
     def _setUnderline(self, checked):
         '''
         Update text editor if Underline button has triggered
         '''
-        fmt = QTextCharFormat()
-        fmt.setFontUnderline(checked)
-        self._mergeFormat(fmt)
-        # don't save current formatting if parent button checked
-        if not self._fontParent.isChecked():
-            self.__font.setUnderline(checked)
+        self.__font.setUnderline(checked)
+        self._setEditorColor(self.__font)
 
     def _textColor(self):
         '''Choose font color'''
@@ -599,31 +577,25 @@ class EditLabelDialog(CommonDialog):
 
     def _updateEditor(self):
         '''
-        Update text editor according to "parent" buttons
+        Update text editor according to state of use parent attributes check boxes
         '''
-        if self._colorParent.isChecked():
+        if self._parentColor.isChecked():
             self._setEditorColor(None)
         else:
             self._setEditorColor(self.__color)
-        if self._fontParent.isChecked():
-            font = self.__node.effectiveLabelFont
-        else:
-            font = self.__font
-            if font is None:
-                font = self.__node.effectiveLabelFont
-        self._fontSizes(font)
-        self._setSizeIndex(font)
-        self._comboFont.setCurrentFont(font)
+        self._setEditorFont(self.__font)
+        self._fontSizes(self.__node.effectiveLabelFont)
+        self._setSizeIndex(self.__node.effectiveLabelFont)
+        self._comboFont.setCurrentFont(self.__node.effectiveLabelFont)
 
     def _setEditorColor(self, color):
         '''
         Update text color of text editor
-
         @type color: QColor
         '''
+        self.__node.setAttributes(labelColor = color)
         fmt = QTextCharFormat()
-        newColor = color if color else self.__node.effectiveLabelColor
-        fmt.setForeground(QBrush(newColor))
+        fmt.setForeground(QBrush(self.__node.effectiveLabelColor))
         self._mergeFormat(fmt)
 
     def _setEditorFont(self, font):
@@ -632,9 +604,12 @@ class EditLabelDialog(CommonDialog):
 
         @type font: QFont
         '''
+        if self._parentFont.isChecked():
+            self.__node.setAttributes(labelFont = None)
+        else:
+            self.__node.setAttributes(labelFont = font)
         fmt = QTextCharFormat()
-        newFont = font if font else self.__node.effectiveLabelFont
-        fmt.setFont(newFont)
+        fmt.setFont(self.__node.effectiveLabelFont)
         self._mergeFormat(fmt)
 
     def _mergeFormat(self, textFormat):
@@ -654,18 +629,8 @@ class EditLabelDialog(CommonDialog):
         and set result code to Accepted
         '''
         modified = {}
-        if self._colorParent.isChecked():
-            self.__color = None
-        else:
-            if self.__color is None:
-                self.__color = self.__node.effectiveLabelColor
-        if self._fontParent.isChecked():
-            self.__font = None
-        else:
-            if self.__font is None:
-                self.__font = self.__node.effectiveLabelFont
-        modified['labelColor'] = self.__color
-        modified['labelFont'] = self.__font
+        modified['labelColor'] = self.__node.labelColor
+        modified['labelFont'] = self.__node.labelFont
         modified['labelText'] = self._editor.toPlainText().replace('\n', ' ')
         modified['propagateLabelFormatting'] = self._propagateFormatting.isChecked()
         self.__newAttributes = modified
@@ -754,7 +719,35 @@ class AboutDialog(CommonDialog):
         #pylint: disable = W0201
         self._logo = QLabel()
         self._logoImage = resource.getImage('logo')
-        self._info = QLabel(self.tr("Collaborative mind map editor"))
+        self._appName = 'HiveMind'
+        self._appDescription = self.tr('Collaborative mind map editor')
+        self._info = QLabel(self._appDescription)
+        self._authorInfo = {'AndreyGolovchenko': {'name': self.tr('Andrey Golovchenko'),
+                'site': 'mailto:golovchenkoaa@gmail.com', 'role': self.tr('core developer')},
+                'AndreyVasilev': {'name': self.tr('Andrey Vasilev'),
+                'site': 'mailto:vamonster@gmail.com', 'role': self.tr('developer/designer')},
+                'AlexanderKulikov': {'name': self.tr('Alexander Kulikov'),
+                'site': 'mailto:asgard1988@yandex.ru', 'role': self.tr('developer')},
+                'OlegKandaurov': {'name': self.tr('Oleg Kandaurov'),
+                'site': 'mailto:kandaurov.oleg@gmail.com', 'role': self.tr('developer')},
+                'IlyaParamonov': {'name': self.tr('Ilya Paramonov'),
+                'site': 'mailto:ivparamonov@gmail.com', 'role': self.tr('technical manager')}}
+        self._participantInfo = {'NicuBuculei': {'name': self.tr('Nicu Buculei'),
+                'site': 'http://nicubunu.ro', 'role': self.tr('HiveMind logo')},
+                'Mentalrey': {'name': self.tr('Mentalrey'),
+                'site': 'http://www.mentalrey.it', 'role': self.tr('Network icons')}}
+        self._licenseLink = 'http://www.gnu.org/licenses/gpl-3.0.html'
+        self._licenseInfo = self.tr('GNU General Public License Version 3')
+        self._fruct = self.tr('Open Innovations Framework Program FRUCT')
+        self._fructLink = 'http://fruct.org'
+        self._bugLink = 'http://linuxlab.corp7.uniyar.ac.ru/projects/hivemind/issues/new'
+        self._siteLink = 'http://linuxlab.corp7.uniyar.ac.ru/'
+        self._linkTemplate = '<a href="%s">%s</a>'
+        self._copyright = '%s &copy; 2010-2011 %s' % (self.tr('Copyright'),
+                self.tr('%s developers') % self._appName)
+        self._license = self.tr('License: %s') % (self._linkTemplate % (self._licenseLink,
+                self._licenseInfo))
+        self._development = self.tr('%s development is supported by') % self._appName
 
 
 class EditEdgeDialog(CommonDialog):
@@ -770,7 +763,7 @@ class EditEdgeDialog(CommonDialog):
         '''
         CommonDialog.__init__(self, parent)
         self.setWindowTitle(self.tr('Edge editor'))
-        self.__node = node
+        self.__node = node.clone()
         self.__newAttributes = {}
         self.__color = None
         self.__widthToButton = None
@@ -806,18 +799,18 @@ class EditEdgeDialog(CommonDialog):
         self._nodeStyleComboBox.addItem(self.tr('Fork'), 'fork')
         # Setting up color view
         self._colorLabel = QLabel(self.tr('Color'))
-        self._colorParent = QCheckBox(self.tr('Parent'))
+        self._parentColor = QCheckBox(self.tr('Parent'))
         self._colorButton = QPushButton(self.tr('Choose color'))
         self._colorButton.connect(SIGNAL('clicked()'), self._edgeColor)
-        self._colorParent.connect(SIGNAL('toggled(bool)'), self._colorButton,
-                                    SLOT('setDisabled(bool)'))
+        self._parentColor.connect(SIGNAL('toggled(bool)'), self._setParentColor)
+        self._colorLabel = ColorLabel()
 
     def _initEditor(self):
         '''Initialize editor'''
         # Initialize color of the Edge
         self.__color = self.__node.edgeColor
-        if self.__color is None:
-            self._colorParent.setChecked(True)
+        self._setEdgeColor(self.__color)
+        self._parentColor.setChecked(self.__color is None)
         self._edgeWidthComboBox.setCurrentIndex(self._edgeWidthComboBox.findData(
                 self.__node.edgeWidth))
         self._edgeStyleComboBox.setCurrentIndex(self._edgeStyleComboBox.findData(
@@ -830,6 +823,27 @@ class EditEdgeDialog(CommonDialog):
         color = QColorDialog.getColor(self.__node.effectiveEdgeColor, self)
         if color.isValid():
             self.__color = color
+            self._setEdgeColor(self.__color)
+
+    def _setParentColor(self, checked):
+        '''
+        Set new state of use parent color check box
+        @type checked: bool
+        '''
+        self._colorButton.setDisabled(checked)
+        if checked:
+            self._setEdgeColor(None)
+        else:
+            self._setEdgeColor(self.__color)
+
+    def _setEdgeColor(self, color):
+        '''
+        Set edge color and update binder according to it
+        @param color: color to set to the node
+        @type color: QColor
+        '''
+        self.__node.setAttributes(edgeColor = color)
+        self._colorLabel.setColor(self.__node.effectiveEdgeColor)
 
     def _accept(self):
         '''
@@ -837,11 +851,7 @@ class EditEdgeDialog(CommonDialog):
         and set result code to Accepted
         '''
         modified = {}
-        if self._colorParent.isChecked():
-            self.__color = None
-        elif self.__color is None:
-            self.__color = self.__node.effectiveEdgeColor
-        modified['edgeColor'] = self.__color
+        modified['edgeColor'] = self.__node.edgeColor
         modified['edgeWidth'] = self._edgeWidthComboBox.itemData(
                 self._edgeWidthComboBox.currentIndex())
         modified['edgeStyle'] = self._edgeStyleComboBox.itemData(
@@ -884,8 +894,8 @@ class SettingsDialog(CommonDialog):
         settings.set(**newSettings)
         if oldLocale != settings.get('locale'):
             QMessageBox.information(self, self.tr('Settings changed'),
-                    self.tr('The language settings will be applied on restart \
-                    of the application!'))
+                    self.tr('The language settings will be applied on restart ' +
+                    'of the application!'))
         QDialog.accept(self)
 
 
@@ -949,7 +959,7 @@ class AffiliationDialog(CommonDialog):
         '''Constructor'''
         CommonDialog.__init__(self, parent)
         self.__model = model
-        self.setWindowTitle(self.tr('Edit affiliations'))
+        self.setWindowTitle(self.tr('Permissions'))
         self._createComponents()
         self._initComponents()
 
@@ -966,7 +976,7 @@ class AffiliationDialog(CommonDialog):
         horizontalHeader.setStretchLastSection(True)
         self.__jidLabel = QLabel(self.tr('JID'))
         self.__jidEdit = QLineEdit()
-        self.__affiliationLabel = QLabel(self.tr('Affiliation'))
+        self.__affiliationLabel = QLabel(self.tr('Permission'))
         self.__affiliationCombo = QComboBox()
         for data, name in self.__model.mapAffiliations.iteritems():
             self.__affiliationCombo.addItem(name, data)
@@ -1001,8 +1011,7 @@ class AffiliationDialog(CommonDialog):
         '''Retrieve info from components and create participant with given access'''
         jidRegexp = QRegExp(VALID_JID)
         if not jidRegexp.exactMatch(self.__jidEdit.text()):
-            QMessageBox.critical(self, self.tr('Incorrect JID!'),
-                    self.tr('Please, enter correct jabber id.'))
+            _showJIDErrorDialog(self)
             return
         self.__model.setAffiliation(jid.internJID(self.__jidEdit.text()),
                 self.__affiliationCombo.itemData(self.__affiliationCombo.currentIndex()))
@@ -1025,13 +1034,14 @@ class NetworkAuthorizationDialog(QMessageBox):
     def __init__(self, requestor, parent = None):
         '''
         @type parent: QWidget
+        @param requestor: Entity that requests authorization
         @type requestor: str
         '''
         QMessageBox.__init__(self, parent)
         self.setIcon(QMessageBox.Question)
-        self.setWindowTitle(self.tr('Authorization request'))
-        self.setText(self.tr('Authorization request from %s') % requestor)
-        self.setInformativeText(self.tr('Do you want to accept authorization request?'))
+        self.setWindowTitle(self.tr('Participation request'))
+        self.setText(self.tr('%s wants to particapate in teamwork') % requestor)
+        self.setInformativeText(self.tr('Do you want to accept pariticipation request?'))
         acceptButton = self.addButton(self.tr('Accept'), QMessageBox.AcceptRole)
         denyButton = self.addButton(self.tr('Deny'), QMessageBox.RejectRole)
         blockButton = self.addButton(self.tr('Block'), QMessageBox.ActionRole)
@@ -1048,7 +1058,7 @@ class NetworkServiceDialog(CommonDialog):
     readable('attributes')
     def __init__(self, parent = None):
         CommonDialog.__init__(self, parent)
-        self.setWindowTitle(self.tr('Create service'))
+        self.setWindowTitle(self.tr('Participation behaviour'))
         self.__attributes = dict()
         self._createComponents()
         self._initComponents()
@@ -1057,9 +1067,9 @@ class NetworkServiceDialog(CommonDialog):
         '''Create components'''
         #pylint: disable = W0201
         self.__openModelRadio = QRadioButton(self.tr('Open'))
-        self.__authModelRadio = QRadioButton(self.tr('Authorize'))
-        self.__rosterModelRadio = QRadioButton(self.tr('Roster'))
-        self.__whitelistModelRadio = QRadioButton(self.tr('Whitelist'))
+        self.__authModelRadio = QRadioButton(self.tr('Interactive'))
+        self.__rosterModelRadio = QRadioButton(self.tr('Contact list'))
+        self.__whitelistModelRadio = QRadioButton(self.tr('White list'))
         self.__accessModelGroup = QButtonGroup()
         self.__accessModelGroup.addButton(self.__openModelRadio)
         self.__accessModelGroup.addButton(self.__rosterModelRadio)
@@ -1075,14 +1085,14 @@ class NetworkServiceDialog(CommonDialog):
     def _initComponents(self):
         '''Create components'''
         mainLayout = QVBoxLayout()
-        firstGroupLayout = QHBoxLayout()
-        firstGroupLayout.addWidget(self.__openModelRadio)
-        firstGroupLayout.addWidget(self.__rosterModelRadio)
-        secondGroupLayout = QHBoxLayout()
-        secondGroupLayout.addWidget(self.__authModelRadio)
-        secondGroupLayout.addWidget(self.__whitelistModelRadio)
-        mainLayout.addLayout(firstGroupLayout)
-        mainLayout.addLayout(secondGroupLayout)
+        accessModelGroupLayout = QGridLayout()
+        accessModelGroupLayout.addWidget(self.__openModelRadio, 0, 0, 1, 1)
+        accessModelGroupLayout.addWidget(self.__rosterModelRadio, 0, 1, 1, 1)
+        accessModelGroupLayout.addWidget(self.__authModelRadio, 1, 0, 1, 1)
+        accessModelGroupLayout.addWidget(self.__whitelistModelRadio, 1, 1, 1, 1)
+        accessModelGroupBox = QGroupBox(self.tr('Trust level'))
+        accessModelGroupBox.setLayout(accessModelGroupLayout)
+        mainLayout.addWidget(accessModelGroupBox)
         mainLayout.addWidget(self.__readOnlyBinder)
         mainLayout.addWidget(self._buttonBox)
         self.setLayout(mainLayout)
@@ -1106,7 +1116,7 @@ class NetworkClientDialog(CommonDialog):
     readable('attributes')
     def __init__(self, rosterModel, parent = None):
         CommonDialog.__init__(self, parent)
-        self.setWindowTitle(self.tr('Create client'))
+        self.setWindowTitle(self.tr('Participate in teamwork'))
         self.__model = rosterModel
         self.__attributes = dict()
         self._createComponents()
@@ -1143,8 +1153,7 @@ class NetworkClientDialog(CommonDialog):
     def _accept(self):
         '''Hide the dialog, update attributes'''
         if not self.__serviceBinder.isValid():
-            QMessageBox.critical(self, self.tr('Incorrect JID!'),
-                    self.tr('Please, enter correct jabber id.'))
+            _showJIDErrorDialog(self)
             return
         self.__attributes = self.__serviceBinder.retrieve()
         settings.set(**self.__attributes)
@@ -1160,7 +1169,7 @@ class NetworkConnectionDialog(CommonDialog):
     readable('attributes')
     def __init__(self, parent = None):
         CommonDialog.__init__(self, parent)
-        self.setWindowTitle(self.tr('Connect to XMPP'))
+        self.setWindowTitle(self.tr('Connect to network'))
         self.__attributes = dict()
         self._createComponents()
         self._initComponents()
@@ -1184,15 +1193,16 @@ class NetworkConnectionDialog(CommonDialog):
         formLayout = QFormLayout()
         formLayout.addRow(self.__userLabel, self.__userBinder)
         formLayout.addRow(self.__passwordLabel, self.__passwordEdit)
-        mainLayout.addLayout(formLayout)
+        credentialsGroupBox = QGroupBox(self.tr('Credentials'))
+        credentialsGroupBox.setLayout(formLayout)
+        mainLayout.addWidget(credentialsGroupBox)
         mainLayout.addWidget(self._buttonBox)
         self.setLayout(mainLayout)
 
     def _accept(self):
         '''Hide the dialog, update attributes'''
         if not self.__userBinder.isValid():
-            QMessageBox.critical(self, self.tr('Incorrect JID!'),
-                    self.tr('Please, enter correct jabber id.'))
+            _showJIDErrorDialog(self)
             return
         self.__attributes = self.__userBinder.retrieve()
         settings.set(**self.__attributes)
