@@ -87,7 +87,7 @@ class MainWindowController(QObject):
             adaptCallable(self.onItemClicked))
         self.connect(self.__mainWindow, SIGNAL('closeEvent'), self._closeEvent)
         _configureApplication(mindMapController)
-        self.__mainWindow.show()
+        self.__mainWindow.showMaximized()
 
     def _setActionsState(self, currentNode):
         '''
@@ -119,6 +119,7 @@ class MainWindowController(QObject):
         self.__actionBag.putNodeAction.setEnabled(self.__mode == self.MODE_TRANSFER)
         self.__actionBag.putNodeBelowAction.setEnabled(self.__mode == self.MODE_TRANSFER)
         self.__actionBag.putNodeAboveAction.setEnabled(self.__mode == self.MODE_TRANSFER)
+        self.__actionBag.showContextMenuAction.setEnabled(self.__mode == self.MODE_NORMAL)
 
     def _connectStateModificationAction(self, action, alteredAttributes, checkable = True):
         '''
@@ -203,6 +204,8 @@ class MainWindowController(QObject):
         self.__actionBag.aboutAction.connect(SIGNAL('triggered()'), self.onAbout)
         self.__actionBag.exitAction.connect(SIGNAL('triggered()'), self._closeMainWindow)
         self.__actionBag.settingsAction.connect(SIGNAL('triggered()'), self.onSettings)
+        self.__actionBag.showContextMenuAction.connect(SIGNAL('triggered()'),
+                self._virtualClick)
 
     def _doUndo(self):
         '''
@@ -265,6 +268,10 @@ class MainWindowController(QObject):
         '''
         self.__networkController.publishCommand(command)
 
+    def _virtualClick(self):
+        '''Emulate mouse click event'''
+        self.__mainWindow.showMenu(True, self.__mindMapScene.currentNode)
+
     def onItemClicked(self, rightButton, item, parent, childLocation):
         if self.__mode == MainWindowController.MODE_NORMAL:
             if item is not None:
@@ -290,7 +297,7 @@ class MainWindowController(QObject):
         newNode = self.__mindMapScene.currentNode.parent.createChildPrototype()
         editor = gui_factory.createEditNodeDialog(newNode)
         editor.connect(SIGNAL('accepted()'), _accept)
-        editor.show()
+        editor.exec_()
 
     def _addSiblingNodeAboveAction(self):
         '''Create and edit a sibling node, add it over selected node'''
@@ -306,7 +313,7 @@ class MainWindowController(QObject):
         newNode = self.__mindMapScene.currentNode.parent.createChildPrototype()
         editor = gui_factory.createEditNodeDialog(newNode)
         editor.connect(SIGNAL('accepted()'), _accept)
-        editor.show()
+        editor.exec_()
 
     def _startNodeMoving(self):
         '''
@@ -433,7 +440,7 @@ class MainWindowController(QObject):
         childNode = self.__mindMapScene.currentNode.createChildPrototype()
         editor = gui_factory.createEditNodeDialog(childNode)
         editor.connect(SIGNAL('accepted()'), _accept)
-        editor.show()
+        editor.exec_()
 
     def removeNode(self):
         '''
@@ -481,10 +488,8 @@ class MainWindowController(QObject):
         self.__mainWindow.close()
 
     def _closeEvent(self):
-        '''
-        Shutdown application
-        '''
-        self.__networkController.shutdownNetwork()
+        '''Close network subsystem'''
+        self.__networkController.terminateNetworkConnection()
 
 
 class MindMapController(QObject):
@@ -493,13 +498,30 @@ class MindMapController(QObject):
     @author: Andrew Vasilev, Alexander Kulikov
     '''
 
-    readable('initialMindMap')
+    readable('initialMindMap', 'undoStack')
 
-    def _getUndoStack(self):
-        '''Get undo stack'''
-        return self.__undoStack
+    def __init__(self, mindMapScene, actionBag):
+        '''
+        @type mindMapScene: MindMapDelegate
+        @type actionBag: ActionBag
+        '''
+        QObject.__init__(self)
+        self.__mindMapScene = mindMapScene
+        self.__actionBag = actionBag
+        self._loadUndoStack(QUndoStack())
+        self.__fileName = None
+        self.__autosaved = False
+        self.__autosaveTimer = QTimer(self)
+        self.__autosaveTimer.setSingleShot(False)
+        self.__autosaveTimer.connect(SIGNAL('timeout()'), self._backupMindMap)
+        settings.connect(self._updateAutosave)
+        self._updateAutosave()
+        self.__actionBag.fileNewAction.connect(SIGNAL('triggered()'), self.onFileNew)
+        self.__actionBag.fileOpenAction.connect(SIGNAL('triggered()'), self.onFileOpen)
+        self.__actionBag.fileSaveAction.connect(SIGNAL('triggered()'), self.onFileSave)
+        self.__actionBag.fileSaveAsAction.connect(SIGNAL('triggered()'), self.onFileSaveAs)
 
-    def _setUndoStack(self, undoStack):
+    def _loadUndoStack(self, undoStack):
         '''
         Load new undo stack
         @param undoStack: UndoStack to be loaded
@@ -515,27 +537,14 @@ class MindMapController(QObject):
         self.__undoStack.connect(SIGNAL('cleanChanged(bool)'),
             adaptCallable(self._undoStackStateChanged))
 
-    undoStack = property(_getUndoStack, _setUndoStack, None, 'Undo stack')
-
-    def __init__(self, mindMapScene, actionBag):
+    def loadUndoStackFromNetwork(self, stack):
         '''
-        @type mindMapScene: MindMapDelegate
-        @type actionBag: ActionBag
+        Deserialize stack and load it
+        @param stack: serialized stack
+        @type stack: str
         '''
-        QObject.__init__(self)
-        self.__mindMapScene = mindMapScene
-        self.__actionBag = actionBag
-        self.undoStack = QUndoStack(self)
-        self.__fileName = None
-        self.__autosaveTimer = QTimer(self)
-        self.__autosaveTimer.setSingleShot(False)
-        self.__autosaveTimer.connect(SIGNAL('timeout()'), self._backupMindMap)
-        settings.connect(self._updateAutosave)
-        self._updateAutosave()
-        self.__actionBag.fileNewAction.connect(SIGNAL('triggered()'), self.onFileNew)
-        self.__actionBag.fileOpenAction.connect(SIGNAL('triggered()'), self.onFileOpen)
-        self.__actionBag.fileSaveAction.connect(SIGNAL('triggered()'), self.onFileSave)
-        self.__actionBag.fileSaveAsAction.connect(SIGNAL('triggered()'), self.onFileSaveAs)
+        self._loadUndoStack(parser.deserializeCommandStack(stack,
+                self.__mindMapScene.mindMap))
 
     def _backupMindMap(self):
         '''Save backup of current map'''
@@ -586,6 +595,7 @@ class MindMapController(QObject):
             try:
                 parser.storeMindMap(self.__fileName, self.__mindMapScene.mindMap)
                 self.__undoStack.setClean()
+                self.__autosaved = False
                 return True
             except IOError, args:
                 QMessageBox.critical(gui_factory.defaultParent(),
@@ -607,16 +617,27 @@ class MindMapController(QObject):
             parser.storeMindMap(fileName, self.__mindMapScene.mindMap)
             self._setFileName(fileName)
             self.__undoStack.setClean()
+            self.__autosaved = False
             return True
         except IOError, args:
             QMessageBox.critical(gui_factory.defaultParent(), self.tr('File save error'),
                     unicode(args[1]))
             return False
 
+    def executeCommandFromNetwork(self, command):
+        '''
+        Deserialize command and execute it
+        @param command: serialized command
+        @type command: str
+        '''
+        command = parser.deserializeCommand(command, self.__mindMapScene.mindMap)
+        self.executeCommand(command)
+
     def executeCommand(self, command):
         '''
         Execute command, created outside main controller
         @param command: command to execute
+        @type command: str
         '''
         if isinstance(command, QUndoCommand):
             self.__undoStack.push(command)
@@ -654,7 +675,7 @@ class MindMapController(QObject):
         @return: False if user canceled action, True otherwise
         @rtype: bool
         '''
-        if self.__undoStack.isClean():
+        if self.__undoStack.isClean() and not self.__autosaved:
             self._removeBackup()
             return True
         decition = self._showSaveChangesBox()
@@ -691,19 +712,6 @@ class MindMapController(QObject):
             return os.path.join(dirname, '.#' + filename + '#')
         return None
 
-    def _getMindMap(self, path):
-        '''
-        Get mindmap from file
-        If path is empty brand new mind map is created
-        @param path: path to mind map file
-        @type path: unicode
-        @rtype: MindMap
-        '''
-        if path is not None:
-            return parser.loadMindMap(path)
-        else:
-            return MindMap()
-
     def loadFile(self, path):
         '''
         Load mind map file and show chosen map.
@@ -713,16 +721,37 @@ class MindMapController(QObject):
         filePath = path
         backup = self._getBackupFilename(path)
         if self._showRecoverDataDialog(backup):
+            self.__autosaved = True
             filePath = backup
+        else:
+            self.__autosaved = False
         try:
-            mindMap = self._getMindMap(filePath)
-            self.__initialMindMap = mindMap
-            self.__undoStack.setClean()
-            self.loadMindMap(self._getMindMap(filePath), path)
+            mindMap = parser.loadMindMap(filePath) if filePath is not None else MindMap()
+            self._setFileName(filePath)
+            self._loadMindMap(mindMap)
         except Exception:
             QMessageBox.critical(gui_factory.defaultParent(), self.tr('File open error'),
                     self.tr('Cannot read mind map from file %s') % os.path.split(path)[1])
 
+    def loadMindMapFromNetwork(self, mindMap):
+        '''
+        Deserialize received mind map and load it
+        @param mindMap: Serialized mind map
+        @type mindMap: str
+        '''
+        self._setFileName(None)
+        self._loadMindMap(parser.mindMapFromString(mindMap))
+
+    def _loadMindMap(self, mindMap):
+        '''
+        Load mindmap into scene
+        @type mindMap: MindMap
+        '''
+        self.__initialMindMap = mindMap
+        self.__undoStack.setClean()
+        self.__undoStack.clear()
+        self.__mindMapScene.setMap(mindMap.clone())
+
     def _showRecoverDataDialog(self, filename):
         '''
         Show dialog to the user asking him/her whether there is a need to recover
@@ -744,21 +773,6 @@ class MindMapController(QObject):
                 return True
         return False
 
-    def loadMindMap(self, mindMap, path = None):
-        '''
-        Load externally created mind map
-
-        @param mindMap: mind map object
-        @type mindMap: MindMap
-
-        @param path: path to the file to store
-        @type path: sting
-        '''
-        self._setFileName(path)
-        # need to store a copy in __initalMindMap
-        self.__mindMapScene.setMap(mindMap)
-        self.__undoStack.clear()
-
 
 def _printHelp():
     '''Print general information about the application'''
@@ -787,7 +801,7 @@ def _configureApplication(controller):
         elif option[0] == '-l':
             log.startLogging(sys.stdout)
     # parsing arguments
-    controller.loadFile(arguments[0] if arguments else None)
+    controller.loadFile(arguments[0].decode('utf-8') if arguments else None)
 
 def _getLocale():
     '''Get locale for the application'''
