@@ -616,6 +616,27 @@ class ActionModificationCommand(QUndoCommand):
         '''Move to next state by calling do function'''
         self.__do()
 
+class ColorLabel(QLabel):
+    '''Label component that displays selected color'''
+
+    def __init__(self, parent = None):
+        QLabel.__init__(self, parent)
+        self.__palette = self.palette()
+        self.__effect = QGraphicsBlurEffect()
+        self.__effect.setBlurRadius(2)
+        self.setGraphicsEffect(self.__effect)
+        self.setAlignment(Qt.AlignCenter)
+        self.setAutoFillBackground(True)
+        self.setFrameStyle(QFrame.StyledPanel | QFrame.Raised)
+
+    def setColor(self, color):
+        '''
+        Set color to dispay on the label
+        @type color: QColor
+        '''
+        self.__palette.setColor(QPalette.Window, color)
+        self.setPalette(self.__palette)
+
 
 class SettingsCreator(QObject):
     '''
@@ -1020,7 +1041,7 @@ class ComboBoxBinder(QComboBox, ComponentBinder):
         self._value = self.__data[index].values().pop()
 
 
-class ColorLabelBinder(QLabel, ComponentBinder):
+class ColorLabelBinder(ColorLabel, ComponentBinder):
     '''
     QColorDialog binder
     @author: Oleg Kandaurov
@@ -1034,16 +1055,10 @@ class ColorLabelBinder(QLabel, ComponentBinder):
         @type color: QColor
         @type parent: QWidget
         '''
-        QLabel.__init__(self, parent)
+        ColorLabel.__init__(self, parent)
         ComponentBinder.__init__(self, paramName, parent)
-        self.__palette = self.palette()
-        self.__effect = QGraphicsBlurEffect()
-        self.__effect.setBlurRadius(2)
-        self.setGraphicsEffect(self.__effect)
-        self.setAlignment(Qt.AlignCenter)
-        self.setAutoFillBackground(True)
-        self.setFrameStyle(QFrame.StyledPanel | QFrame.Raised)
         self._setValue(color)
+        self.setColor(color)
 
     def open(self):
         '''
@@ -1052,14 +1067,6 @@ class ColorLabelBinder(QLabel, ComponentBinder):
         color = QColorDialog.getColor(self._value, self)
         self._setValue(color)
 
-    def _setLabelColor(self, color):
-        '''
-        Change color of the label
-        @type color: QColor
-        '''
-        self.__palette.setColor(QPalette.Window, color)
-        self.setPalette(self.__palette)
-
     def isValid(self, color):
         '''
         @return: whether color valid or not
@@ -1073,7 +1080,7 @@ class ColorLabelBinder(QLabel, ComponentBinder):
         @param value: new value
         '''
         if self.isValid(value):
-            self._setLabelColor(value)
+            self.setColor(value)
             self._value = value
 
 
