@@ -184,9 +184,9 @@ class MaemoEditLabelDialog(MaemoDialogMixin, EditLabelDialog):
         self._underlineAction.setIcon(QIcon(resource.getImage('node_editor_underline')))
         toolbar.addAction(self._underlineAction)
         secondaryLayout = QHBoxLayout()
-        secondaryLayout.addWidget(self._fontParent)
+        secondaryLayout.addWidget(self._parentFont)
         secondaryLayout.addSpacing(20)
-        secondaryLayout.addWidget(self._colorParent)
+        secondaryLayout.addWidget(self._parentColor)
         secondaryLayout.addWidget(self._colorButton)
         scalingWidget = ScalingWidget(self._editor, 2.0)
         self._editor.setFrameShape(QFrame.Box)
@@ -258,38 +258,52 @@ class MaemoAboutDialog(AboutDialog):
         #pylint: disable = W0201
         AboutDialog._createComponents(self)
         self._logo.setPixmap(self._logoImage)
-        self._visitWebsite = QPushButton(self.tr("Visit website"))
-        self._reportBug = QPushButton(self.tr("Report bug"))
-        self._name = QLabel("<h2>HiveMind %s</h2>" % __version__.VERSION)
+        self._visitWebsite = QPushButton(self.tr('Visit website'))
+        self._reportBug = QPushButton(self.tr('Report bug'))
+        self._name = QLabel('<h2>%s %s</h2>' % (self._appName, __version__.VERSION))
         self._about = QTextBrowser()
-        self._about.setHtml(self.tr('''<br><br><br><br><br><br><br><br><br><center>
-                            This application  is licensed under the terms <br>of the
-                            <a href="http://www.gnu.org/licenses/gpl-3.0.html">
-                            GNU General Public License v3</a>
-                            <p><br>Copyright &copy; 2010-2011 HiveMind developers</center>
-                            <ul style="list-style-type: square;margin: 0px 0px 0px 40px">
-                            <li><a href="mailto:golovchenkoaa@gmail.com">Andrey Golovchenko</a>, core developer
-                            <li><a href="mailto:vamonster@gmail.com">Andrey Vasilev</a>, developer/designer
-                            <li><a href="mailto:asgard1988@yandex.ru">Alexander Kulikov</a>, developer
-                            <li><a href="mailto:kandaurov.oleg@gmail.com">Oleg Kandaurov</a>, developer
-                            <li><a href="mailto:ivparamonov@gmail.com">Ilya Paramonov</a>, technical manager</ul>
-                            <br><center>HiveMind development is supported by<br>
-                            <a href="http://fruct.org/">
-                            Open Innovations Framework Program FRUCT</a>
-                            <br><br>HiveMind logo by <a href="http://nicubunu.ro">Nicu Buculei</a> (nicubunu)
-                            <br>Notification icons by <a href="http://www.mentalrey.it/">Mentalrey</a>
-                            <br><br><br><br><br><br><br><br><br>
-                            </center>'''))
+        self._about.setHtml(('<br><br><br><br><br><br><br><br><br>' +
+                '<center>%s<br>%s</center>' +
+                '<ul style="list-style-type: square;margin: 0px 0px 0px 40px">' +
+                '<li>%s<li>%s<li>%s<li>%s<li>%s</ul><br>' +
+                '<center>%s<br>%s<br><br>%s<br>%s' +
+                '<br><br><br><br><br><br><br><br><br></center>') % (
+                self._license, self._copyright,
+                self._generateAuthorInfo('AndreyVasilev'),
+                self._generateAuthorInfo('OlegKandaurov'),
+                self._generateAuthorInfo('AlexanderKulikov'),
+                self._generateAuthorInfo('IlyaParamonov'),
+                self._generateAuthorInfo('AndreyGolovchenko'),
+                self._development, (self._linkTemplate % (self._fructLink, self._fruct)),
+                self._generatePartcipantInfo('NicuBuculei'),
+                self._generatePartcipantInfo('Mentalrey')))
         self._about.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
         self._about.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
         self._about.setOpenExternalLinks(True)
         self._scrollBar = self._about.verticalScrollBar()
         self._scrollBar.setSingleStep(1)
         self._scrollBar.setRepeatAction(QAbstractSlider.SliderSingleStepAdd, 0, 70)
-        self._scrollBar.connect(SIGNAL('actionTriggered(int)'),
-                                 adaptCallable(self._scroll))
-        self._visitWebsite.connect(SIGNAL('clicked()'), openWebsite)
-        self._reportBug.connect(SIGNAL('clicked()'), openBugReport)
+        self._scrollBar.connect(SIGNAL('actionTriggered(int)'), adaptCallable(self._scroll))
+        self._visitWebsite.connect(SIGNAL('clicked()'), self._openWebsite)
+        self._reportBug.connect(SIGNAL('clicked()'), self._openBugReport)
+
+    def _generatePartcipantInfo(self, name):
+        '''
+        Generate formatted information about participant person
+        @type name: str
+        '''
+        infoTemplate = ('%s: %s')
+        return infoTemplate % (self._participantInfo[name]['role'], self._linkTemplate %
+            (self._participantInfo[name]['site'], self._participantInfo[name]['name']))
+
+    def _generateAuthorInfo(self, name):
+        '''
+        Generate formatted information about author person
+        @type name: str
+        '''
+        infoTemplate = ('<a href="%s">%s</a>, %s')
+        return infoTemplate % (self._authorInfo[name]['site'], self._authorInfo[name]['name'],
+                self._authorInfo[name]['role'])
 
     def _initComponents(self):
         '''Form initialization'''
@@ -304,10 +318,17 @@ class MaemoAboutDialog(AboutDialog):
         mainLayout.addLayout(buttonsLayout, 16, 14, 4, 6)
         self.setLayout(mainLayout)
 
+    def _openWebsite(self):
+        '''Open project web page'''
+        QDesktopServices.openUrl(QUrl(self._siteLink))
+
+    def _openBugReport(self):
+        '''Open bug report page'''
+        QDesktopServices.openUrl(QUrl(self._bugLink))
+
     def _scroll(self, action):
         '''
         Handle action from vertical scroll bar
-
         @type action: int
         '''
         if action == QAbstractSlider.SliderSingleStepAdd:
@@ -334,7 +355,8 @@ class MaemoEditEdgeDialog(MaemoDialogMixin, EditEdgeDialog):
     def _initComponents(self):
         '''Form initialization'''
         colorLayout = QHBoxLayout()
-        colorLayout.addWidget(self._colorParent)
+        colorLayout.addWidget(self._parentColor)
+        colorLayout.addWidget(self._colorLabel)
         colorLayout.addWidget(self._colorButton)
         mainLayout = QGridLayout()
         mainLayout.addWidget(self._widthLabel, 0, 0)
@@ -383,7 +405,7 @@ class MaemoSettingsDialog(MaemoDialogMixin, SettingsDialog):
         self._autosave = SettingsCreator(['autosaveEnabled', 'autosaveInterval'])
         autosaveTab = QWidget()
         autosaveTab.setLayout(self._autosave.getLayout())
-        self._maxTextWidth = SettingsCreator(['defaultZoomLevel','maxNodeTextWidth'])
+        self._maxTextWidth = SettingsCreator(['defaultZoomLevel', 'maxNodeTextWidth'])
         otherTab = QWidget()
         otherTab.setLayout(self._maxTextWidth.getLayout())
         tabWidget.addTab(generalTab, self.tr('General'))
@@ -427,16 +449,22 @@ class MaemoExtendedMenuDialog(QDialog):
     Extended menu dialog for Maemo platform
     @author: Alexander Kulikov
     '''
-    def __init__(self, actionBag, freezeTime = 0, parent = None):
+    def __init__(self, actionBag, parent = None, freezeTime = 0, showHints = False):
         '''
         @type actionBag: ActionBag
         @param freezeTime: Time interval during which dialog can not be rejected
         @type freezeTime: int
-        @type parent: None
+        @param showHints: Show hints or not
+        @type showHints: bool
+        @type parent: QWidget
         '''
         QDialog.__init__(self, parent)
-        self.setWindowTitle(self.tr('Extended menu'))
+        if showHints:
+            self.setWindowTitle(self.tr('Context menu usage'))
+        else:
+            self.setWindowTitle(self.tr('Extended menu'))
         self.__freezed = freezeTime != 0
+        self.__showHints = showHints
         QTimer.singleShot(freezeTime, self._unfreeze)
         self._createComponents(actionBag)
 
@@ -445,46 +473,55 @@ class MaemoExtendedMenuDialog(QDialog):
         Create dialog widgets
         @type actionBag: ActionBag
         '''
+        def createLabel(text):
+            '''Creates label with special properties'''
+            label = QLabel(text)
+            label.setWordWrap(True)
+            label.setAlignment(Qt.AlignCenter)
+            return label
+
         layout = QGridLayout()
         font = QFont()
         font.setPixelSize(28)
-        singleClickLabel = QLabel(self.tr('Single-click on the node to show the main menu:'))
-        singleClickLabel.setFont(font)
-        doubleClickLabel = QLabel(
-                self.tr('Double-click on the node to show the additional menu:'))
-        doubleClickLabel.setFont(font)
-        layout.addWidget(singleClickLabel, 0, 0, 1, 4, Qt.AlignCenter)
-        layout.addWidget(doubleClickLabel, 3, 0, 1, 4, Qt.AlignCenter)
+        if self.__showHints:
+            singleClickLabel = QLabel(self.tr('Single-click on the node to show ' +
+                    'the main menu:'))
+            singleClickLabel.setFont(font)
+            doubleClickLabel = QLabel(self.tr('Double-click on the node to show the ' +
+                    'additional menu:'))
+            doubleClickLabel.setFont(font)
+            layout.addWidget(singleClickLabel, 0, 0, 1, 4, Qt.AlignCenter)
+            layout.addWidget(doubleClickLabel, 3, 0, 1, 4, Qt.AlignCenter)
         layout.addWidget(self._createActionWidget(actionBag.addNodeAction), 1, 0,
                 Qt.AlignCenter)
-        layout.addWidget(QLabel(self.tr('Add node')), 2, 0, Qt.AlignHCenter | Qt.AlignTop)
+        layout.addWidget(createLabel(self.tr('Add node')), 2, 0, Qt.AlignHCenter | Qt.AlignTop)
         layout.addWidget(self._createActionWidget(actionBag.editNodeAction), 1, 1,
                 Qt.AlignCenter)
-        layout.addWidget(QLabel(self.tr('Edit node')), 2, 1, Qt.AlignHCenter |
+        layout.addWidget(createLabel(self.tr('Edit node')), 2, 1, Qt.AlignHCenter |
                 Qt.AlignTop)
         layout.addWidget(self._createActionWidget(actionBag.removeNodeAction), 1, 2,
                 Qt.AlignCenter)
-        layout.addWidget(QLabel(self.tr('Remove node')), 2, 2, Qt.AlignHCenter |
+        layout.addWidget(createLabel(self.tr('Remove node')), 2, 2, Qt.AlignHCenter |
                 Qt.AlignTop)
         layout.addWidget(self._createActionWidget(actionBag.foldNodeAction), 1, 3,
                 Qt.AlignCenter)
-        layout.addWidget(QLabel(self.tr('<center>Fold/unfold<br>node subtree</center>')),
+        layout.addWidget(createLabel(self.tr('Fold/unfold node subtree')),
                 2, 3, Qt.AlignHCenter | Qt.AlignTop)
         layout.addWidget(self._createActionWidget(actionBag.editNodeIconsAction), 4, 0,
                 Qt.AlignCenter)
-        layout.addWidget(QLabel(self.tr('Select icons')), 5, 0, Qt.AlignHCenter |
+        layout.addWidget(createLabel(self.tr('Select icons')), 5, 0, Qt.AlignHCenter |
                 Qt.AlignTop)
         layout.addWidget(self._createActionWidget(actionBag.editEdgeAction), 4, 1,
                 Qt.AlignCenter)
-        layout.addWidget(QLabel(self.tr('Edit edge')), 5, 1, Qt.AlignHCenter |
+        layout.addWidget(createLabel(self.tr('Edit edge')), 5, 1, Qt.AlignHCenter |
                 Qt.AlignTop)
         layout.addWidget(self._createActionWidget(actionBag.enterTransferModeAction), 4, 2,
                 Qt.AlignCenter)
-        layout.addWidget(QLabel(self.tr('Move node')), 5, 2, Qt.AlignHCenter |
+        layout.addWidget(createLabel(self.tr('Move node')), 5, 2, Qt.AlignHCenter |
                 Qt.AlignTop)
         layout.addWidget(self._createActionWidget(actionBag.editLabelAction), 4, 3,
                 Qt.AlignCenter)
-        layout.addWidget(QLabel(self.tr('Edit edge label')), 5, 3, Qt.AlignHCenter |
+        layout.addWidget(createLabel(self.tr('Edit edge label')), 5, 3, Qt.AlignHCenter |
                 Qt.AlignTop)
         self.setLayout(layout)
 
@@ -537,14 +574,3 @@ class MaemoNetworkConnectionDialog(MaemoDialogMixin, NetworkConnectionDialog):
     def __init__(self, parent = None):
         NetworkConnectionDialog.__init__(self, parent)
         MaemoDialogMixin.__init__(self)
-
-
-def openWebsite():
-    '''Open project web page'''
-    QDesktopServices.openUrl(QUrl(
-            'https://linuxlab.corp7.uniyar.ac.ru/projects/hivemind'))
-
-def openBugReport():
-    '''Open bug report page'''
-    QDesktopServices.openUrl(QUrl(
-            'https://linuxlab.corp7.uniyar.ac.ru/projects/hivemind/issues/new'))
