@@ -160,18 +160,19 @@ class MaemoMainWindow(AbstractMainWindow):
         menu.addAction(self._actionBag.redoAction)
         menu.addAction(self._actionBag.startServiceAction)
         menu.addAction(self._actionBag.startClientAction)
-        menu.addAction(self._actionBag.disconnectXMPPAction)
         menu.addAction(self._actionBag.editAffiliationAction)
+        menu.addAction(self._actionBag.stopProtocolAction)
+        menu.addAction(self._actionBag.disconnectXMPPAction)
 
     def showMenu(self, rightButton, item):
         '''Show one of the two menus according to the button clicked'''
         if settings.get('firstClick') is True:
-            extendedMenu = MaemoExtendedMenuDialog(self.__actionBag, 5000)
+            extendedMenu = MaemoExtendedMenuDialog(self.__actionBag, self, 5000, True)
             firstClick = False
             settings.set(firstClick = firstClick)
             extendedMenu.exec_()
         elif settings.get('useExtendedMenu') is True:
-            extendedMenu = MaemoExtendedMenuDialog(self.__actionBag)
+            extendedMenu = MaemoExtendedMenuDialog(self.__actionBag, self)
             extendedMenu.exec_()
         else:
             menu = self.__additionalMenu if rightButton else self.__menu
