@@ -138,7 +138,8 @@ __COLORS = set(('color', 'background_color', 'edgeColor', 'labelColor'))
 __FONTS = set(('font', 'labelFont'))
 '''QFont attributes'''
 
-__BOOLEANS = set(('folded', 'propagate_formatting'))
+__BOOLEANS = set(('folded', 'propagate_formatting', 'propagateNodeFormatting',
+        'propagateLabelFormatting'))
 '''Attribute that store boolean values'''
 
 def _castAttributes(attributes, toLowerCase = True):
